summaryrefslogtreecommitdiffstats
path: root/kexi/plugins/scripting/scripts/importxhtml
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2011-12-21 14:05:41 -0600
committerTimothy Pearson <[email protected]>2011-12-21 14:05:41 -0600
commit2d6954f69caf63ed5057bd8e1405a65d7d970292 (patch)
tree88e6436b2e81d4e68313f02a9021054252e14cc4 /kexi/plugins/scripting/scripts/importxhtml
parentf0de9e167e289ab7dc33e57f077c1f04ec7c68c8 (diff)
downloadkoffice-2d6954f69caf63ed5057bd8e1405a65d7d970292.tar.gz
koffice-2d6954f69caf63ed5057bd8e1405a65d7d970292.zip
Rename obsolete tq methods to standard names
Diffstat (limited to 'kexi/plugins/scripting/scripts/importxhtml')
-rwxr-xr-xkexi/plugins/scripting/scripts/importxhtml/ImportXHTML.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/kexi/plugins/scripting/scripts/importxhtml/ImportXHTML.py b/kexi/plugins/scripting/scripts/importxhtml/ImportXHTML.py
index 6ca94f9a..200b3dee 100755
--- a/kexi/plugins/scripting/scripts/importxhtml/ImportXHTML.py
+++ b/kexi/plugins/scripting/scripts/importxhtml/ImportXHTML.py
@@ -124,9 +124,9 @@ class SaxInput:
was parsed. """
if self.field != None:
# the xml-data is tqunicode and we need to encode it
# to latin-1 cause KexiDB deals only with latin-1.
- u = tqunicode(chars[offset:offset+length])
+ u = unicode(chars[offset:offset+length])
self.field.append(u.encode("latin-1"))
# start the job
@@ -124,9 +124,9 @@ class SaxInput:
was parsed. """
if self.field != None:
- # the xml-data is tqunicode and we need to encode it
+ # the xml-data is unicode and we need to encode it
# to latin-1 cause KexiDB deals only with latin-1.